from .core import Tecana

__version__ = '1.1.0'

_ta = Tecana()

adi = _ta.adi
adi_m = _ta.adi_m
adi_t = _ta.adi_t
ai = _ta.ai
ai_m = _ta.ai_m
ai_t = _ta.ai_t
ao = _ta.ao
atr = _ta.atr
atr_m = _ta.atr_m
atr_t = _ta.atr_t
atr_v = _ta.atr_v
awo = _ta.awo
awo_m = _ta.awo_m
awo_t = _ta.awo_t
bb = _ta.bb
bb_t = _ta.bb_t
bb_v = _ta.bb_v
bb_z = _ta.bb_z
cc = _ta.cc
cc_m = _ta.cc_m
cc_z = _ta.cc_z
cci = _ta.cci
cci_m = _ta.cci_m
cci_z = _ta.cci_z
ce = _ta.ce
ci = _ta.ci
ci1_v = _ta.ci1_v
ci2_v = _ta.ci2_v
cmf = _ta.cmf
cmf_t = _ta.cmf_t
cmo = _ta.cmo
cmo_t = _ta.cmo_t
custom = _ta.custom
dc = _ta.dc
dc_m = _ta.dc_m
dc_t = _ta.dc_t
dc_z = _ta.dc_z
di = _ta.di
di_m = _ta.di_m
di_z = _ta.di_z
dma = _ta.dma
dma_t = _ta.dma_t
dpo = _ta.dpo
dpo_m = _ta.dpo_m
dpo_z = _ta.dpo_z
dx = _ta.dx
dx_t = _ta.dx_t
dx_z = _ta.dx_z
ema = _ta.ema
ema_m = _ta.ema_m
ema_z = _ta.ema_z
eom = _ta.eom
eom_m = _ta.eom_m
eom_t = _ta.eom_t
eom_z = _ta.eom_z
eri = _ta.eri
eri_t = _ta.eri_t
fi = _ta.fi
fi_t = _ta.fi_t
fi_z = _ta.fi_z
fr = _ta.fr
fr_m = _ta.fr_m
fr_z = _ta.fr_z
ha = _ta.ha
ha_m = _ta.ha_m
ha_t = _ta.ha_t
ic = _ta.ic
ic_m = _ta.ic_m
ic_t = _ta.ic_t
ic_z = _ta.ic_z
kama = _ta.kama
kama_m = _ta.kama_m
kama_t = _ta.kama_t
kama_z = _ta.kama_z
kc = _ta.kc
kc_m = _ta.kc_m
kc_t = _ta.kc_t
kc_z = _ta.kc_z
kst = _ta.kst
kst_m = _ta.kst_m
kst_t = _ta.kst_t
lr = _ta.lr
lr_t = _ta.lr_t
macd = _ta.macd
macd_m = _ta.macd_m
macd_t = _ta.macd_t
mae = _ta.mae
mae_m = _ta.mae_m
mae_z = _ta.mae_z
mfi = _ta.mfi
mfi_t = _ta.mfi_t
mfi_z = _ta.mfi_z
mi = _ta.mi
mp = _ta.mp
null = _ta.null
null_m = _ta.null_m
null_t = _ta.null_t
null_v = _ta.null_v
null_z = _ta.null_z
nvi = _ta.nvi
nvi_t = _ta.nvi_t
obv = _ta.obv
obv_m = _ta.obv_m
obv_t = _ta.obv_t
pc = _ta.pc
pc_t = _ta.pc_t
pp = _ta.pp
pp_m = _ta.pp_m
pp_z = _ta.pp_z
ppo = _ta.ppo
ppo_m = _ta.ppo_m
ppo_t = _ta.ppo_t
proc = _ta.proc
proc_m = _ta.proc_m
proc_z = _ta.proc_z
psar = _ta.psar
psar2 = _ta.psar2
psar_m = _ta.psar_m
psar_t = _ta.psar_t
pvo = _ta.pvo
pvo_m = _ta.pvo_m
pvo_t = _ta.pvo_t
roc = _ta.roc
roc_m = _ta.roc_m
roc_t = _ta.roc_t
roc_z = _ta.roc_z
rsi = _ta.rsi
rsi_m = _ta.rsi_m
rsi_z = _ta.rsi_z
sma = _ta.sma
sma_m = _ta.sma_m
sma_z = _ta.sma_z
so = _ta.so
so_m = _ta.so_m
so_t = _ta.so_t
so_z = _ta.so_z
sroc = _ta.sroc
sroc_t = _ta.sroc_t
srsi = _ta.srsi
srsi_m = _ta.srsi_m
srsi_z = _ta.srsi_z
stc = _ta.stc
stc_m = _ta.stc_m
stc_z = _ta.stc_z
sz = _ta.sz
sz_z = _ta.sz_z
tmf = _ta.tmf
tmf_t = _ta.tmf_t
tmo = _ta.tmo
tmo_m = _ta.tmo_m
tmo_z = _ta.tmo_z
tp = _ta.tp
trix = _ta.trix
trix_m = _ta.trix_m
trix_t = _ta.trix_t
tsi = _ta.tsi
tsi_m = _ta.tsi_m
tsi_t = _ta.tsi_t
tsi_z = _ta.tsi_z
tti = _ta.tti
tti_t = _ta.tti_t
tv = _ta.tv
tv_z = _ta.tv_z
ui = _ta.ui
ui_v = _ta.ui_v
uo = _ta.uo
uo_m = _ta.uo_m
uo_t = _ta.uo_t
uo_z = _ta.uo_z
vhf = _ta.vhf
vhf1_v = _ta.vhf1_v
vhf2_v = _ta.vhf2_v
vi = _ta.vi
vi_m = _ta.vi_m
vi_t = _ta.vi_t
vo = _ta.vo
vo_v = _ta.vo_v
vpt = _ta.vpt
vpt_m = _ta.vpt_m
vpt_t = _ta.vpt_t
vr = _ta.vr
vroc = _ta.vroc
vroc_t = _ta.vroc_t
vs = _ta.vs
vs_m = _ta.vs_m
vs_z = _ta.vs_z
vwap = _ta.vwap
vwap_t = _ta.vwap_t
wad = _ta.wad
wad_z = _ta.wad_z
wma = _ta.wma
wma_m = _ta.wma_m
wma_z = _ta.wma_z
wr = _ta.wr
wr_t = _ta.wr_t
wr_z = _ta.wr_z

__all__ = ['adi', 'adi_m', 'adi_t', 'ai', 'ai_m', 'ai_t', 'ao', 'atr',
           'atr_m', 'atr_t', 'atr_v', 'awo', 'awo_m', 'awo_t', 'bb',
           'bb_t', 'bb_v', 'bb_z', 'cc', 'cc_m', 'cc_z', 'cci', 'cci_m',
           'cci_z', 'ce', 'ci', 'ci1_v', 'ci2_v', 'cmf', 'cmf_t', 'cmo',
           'cmo_t', 'custom', 'dc', 'dc_m', 'dc_t', 'dc_z', 'di', 'di_m',
           'di_z', 'dma', 'dma_t', 'dpo', 'dpo_m', 'dpo_z', 'dx', 'dx_t',
           'dx_z', 'ema', 'ema_m', 'ema_z', 'eom', 'eom_m', 'eom_t', 'eom_z',
           'eri', 'eri_t', 'fi', 'fi_t', 'fi_z', 'fr', 'fr_m', 'fr_z', 'ha',
           'ha_m', 'ha_t', 'ic', 'ic_m', 'ic_t', 'ic_z', 'kama', 'kama_m',
           'kama_t', 'kama_z', 'kc', 'kc_m', 'kc_t', 'kc_z', 'kst', 'kst_m',
           'kst_t', 'lr', 'lr_t', 'macd', 'macd_m', 'macd_t', 'mae', 'mae_m',
           'mae_z', 'mfi', 'mfi_t', 'mfi_z', 'mi', 'mp', 'null', 'null_m',
           'null_t', 'null_v', 'null_z', 'nvi', 'nvi_t', 'obv', 'obv_m',
           'obv_t', 'pc', 'pc_t', 'pp', 'pp_m', 'pp_z', 'ppo', 'ppo_m',
           'ppo_t', 'proc', 'proc_m', 'proc_z', 'psar', 'psar2', 'psar_m',
           'psar_t', 'pvo', 'pvo_m', 'pvo_t', 'roc', 'roc_m', 'roc_t', 'roc_z',
           'rsi', 'rsi_m', 'rsi_z', 'sma', 'sma_m', 'sma_z', 'so', 'so_m', 'so_t',
           'so_z', 'sroc', 'sroc_t', 'srsi', 'srsi_m', 'srsi_z', 'stc', 'stc_m',
           'stc_z', 'sz', 'sz_z', 'tmf', 'tmf_t', 'tmo', 'tmo_m', 'tmo_z', 'tp',
           'trix', 'trix_m', 'trix_t', 'tsi', 'tsi_m', 'tsi_t', 'tsi_z', 'tti',
           'tti_t', 'tv', 'tv_z', 'ui', 'ui_v', 'uo', 'uo_m', 'uo_t', 'uo_z', 'vhf',
           'vhf1_v', 'vhf2_v', 'vi', 'vi_m', 'vi_t', 'vo', 'vo_v', 'vpt', 'vpt_m',
           'vpt_t', 'vr', 'vroc', 'vroc_t', 'vs', 'vs_m', 'vs_z', 'vwap', 'vwap_t',
           'wad', 'wad_z', 'wma', 'wma_m', 'wma_z', 'wr', 'wr_t', 'wr_z']
